@@ -9,7 +9,7 @@
     Copyright (c) 2005 Etersoft
     Copyright (c) 2005 Vitaly Lipatov <lav@etersoft.ru>
 
-    $Id: filesystem.c,v 1.8 2005/07/21 18:30:26 vitlav Exp $
+    $Id: filesystem.c,v 1.12 2008/02/14 22:37:08 vitlav Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -44,8 +44,9 @@
 # include <langinfo.h>
 #endif
 
+/* FIXME: due typedef int (*__compar_fn_t) (__const void *, __const void *); */
 /*! Internal: charset comparing for bsearch */
-static int charset_cmp( const void *name, const void *entry )
+static int charset_cmp( __const void *name, __const void *entry )
 {
     const struct charset_entry *charset = (const struct charset_entry *)entry;
     return strcmp( (const char *)name, charset->charset_name );
@@ -53,7 +54,7 @@ static int charset_cmp( const void *name, const void *entry )
 
 
 /*! Returns codepage from charset */
-const int natspec_get_codepage_by_charset(const char *charset)
+int natspec_get_codepage_by_charset(const char *charset)
 {
 	const struct charset_entry *entry;
 	char *cs = natspec_humble_charset(charset);
@@ -89,6 +90,12 @@ const char *natspec_get_filename_encoding(const char *locale)
 	/* Try get from environment variable (it can be comma-separated,
 	 * but we using first part only */
 	const char *buf = getenv("G_FILENAME_ENCODING");
+	/* The special token "@locale" specifies the character set for the current locale. */
+	/* Note: We already do not use G_FILENAME_ENCODING if it contains not locale name */
+	/* TODO: will we use strstr here? */
+	if (buf != NULL && !strcmp(buf, "@locale"))
+		buf = NULL;
+
 	if (!_n_isempty(buf) && locale != NULL && locale[0] == '\0')
 	{
 		/* If get from env G_FILENAME_ENCODING non empty string, and use current locale (""),
