@@ -1,14 +1,13 @@
-//!!!!!!!  dlopen !!!!!!!
 /*
     src/natspec.c
-	
-	command line util for access to libnatspec functions
+
+    command line util for access to libnatspec functions
 
     NATSPEC library
-    Copyright (c) 2005 Etersoft
-    Copyright (c) 2005 Vitaly Lipatov <lav@etersoft.ru>
+    Copyright (c) 2005, 2015 Etersoft
+    Copyright (c) 2005, 2015 Vitaly Lipatov <lav@etersoft.ru>
 
-    $Id: natspec.c,v 1.21 2005/07/21 22:23:08 vitlav Exp $
+    $Id: natspec.c,v 1.22 2005/09/03 18:59:28 vitlav Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -27,6 +26,7 @@
 */
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 #include <strings.h>
 #include <assert.h>
@@ -44,11 +44,15 @@
 # include <langinfo.h>
 #endif
 
+#define VERBOSE if (verbose) printf
+
+/* natspec internals */
+char *natspec_internal_get_locale_from_env();
 
 char *charset_type;
 char *locale, *transliterate;
 int version, verbose, fsenc, fcodepage, nls, flag_help, info;
-int flag_locale, utf8, country_id;
+int utf8, country_id, get_system_locale, get_user_locale;
 
 #if defined HAVE_LIBPOPT
 poptContext context = NULL;
@@ -58,10 +62,14 @@ struct poptOption options[] =
      "print codepage", ""},
     {"fsenc", 'f', POPT_ARG_NONE,  &fsenc, 1,
      "print filesystem encoding", ""},
-	{"utf8", 0, POPT_ARG_NONE,  &utf8, 1,
+    {"utf8", 0, POPT_ARG_NONE,  &utf8, 1,
      "return 0 if locale is utfed", ""},
-	{"country-id", 0, POPT_ARG_NONE,  &country_id, 1,
+    {"country-id", 0, POPT_ARG_NONE,  &country_id, 1,
      "print country ID (international numbering)", ""},
+    {"locale", 'l', POPT_ARG_NONE,  &get_user_locale, 1,
+     "print current user locale", ""},
+    {"system-locale", 0, POPT_ARG_NONE,  &get_system_locale, 1,
+     "print system locale", ""},
     {"info", 'i', POPT_ARG_NONE,  &info, 0,
      "print overall encoding/charset info for your system", ""},
     {"transl", 'a', POPT_ARG_STRING,  &transliterate, 1,
@@ -93,15 +101,13 @@ static const char *get_charset(char *charset_type)
 		type = NATSPEC_UNIXCS;
 	else
 	{
-		if (verbose) printf("We do not know %s type of encoding\n",charset_type);
+		VERBOSE("We do not know %s type of encoding\n",charset_type);
 		printf("ASCII\n");
 		exit(1);
 	}
 	charset = natspec_get_charset_by_locale(type, locale);
-	if (verbose)
-		printf("Charset of '%s' system: %s\n", charset_type, charset);
-	else
-		printf("%s\n",charset);
+	VERBOSE("Charset of '%s' system: ", charset_type);
+	printf("%s\n", charset);
 	return charset;
 }
 
@@ -132,22 +138,26 @@ int main(int argc, const char** argv)
       poptFreeContext(poptCtx);
 	}
 */	
-    if(flag_help)
+	if(flag_help)
 	{
-	poptPrintHelp(poptCtx, stdout, 0);
-    exit(0);
+		poptPrintHelp(poptCtx, stdout, 0);
+		exit(0);
 	}
 
 #else
 	fprintf(stderr, "Compiled without popt. Exit\n");
 	exit(1);
 #endif
+
+        /* Print overall information by default */
 	if (argc == 1)
 		info = 1;
+
 	if (version || info)
 	{
-		printf("%s, compiled %s\n",PACKAGE_STRING,__DATE__);
-		if (!info) exit(0);
+		printf("%s, compiled %s\n", PACKAGE_STRING,__DATE__);
+		if (!info)
+			exit(0);
 	}
 	if (transliterate)
 	{
@@ -167,46 +177,54 @@ int main(int argc, const char** argv)
 	}
 	if (info)
 	{
-		printf(" === Overall information ===\n");
+		printf(" === Overall locale information ===\n");
 		verbose = 1;
 	}
 	locale = natspec_get_current_locale();
-	if (flag_locale || info)
+	if (get_user_locale || info)
 	{
-		if (verbose) printf("Current locale: ");
-		printf("%s",locale);
-		if (verbose) puts("");
+		VERBOSE("Current user locale: ");
+		printf("%s", locale);
+		if (verbose && !natspec_internal_get_locale_from_env())
+			printf(" (got from system locale)");
+		puts("");
+	}
+	if (get_system_locale || info)
+	{
+		VERBOSE("System locale: ");
+		printf("%s\n", natspec_get_system_locale());
+		if (!info)
+			exit(0);
 	}
-	if (verbose)
-		printf("System locale: %s\n", natspec_get_system_locale());
 	if (fsenc || info)
 	{
 		const char *buf;
-		if (verbose) printf("Filename encoding in iconv/nls form: ");
+		VERBOSE("Filename encoding in iconv/nls form: ");
 		buf = natspec_get_filename_encoding("");
-		printf("%s",buf);
-		if (verbose) puts("");
-		if (!info) exit(0);
+		printf("%s\n",buf);
+		if (!info)
+			exit(0);
 	}
 	if (country_id || info)
 	{
 		int id;
-		if (verbose) printf("Country ID (for DOS): ");
-//		id = natspec_get_country_id();
-		printf("%d", id);
-		if (verbose) puts("");
-		if (!info) exit(0);
+		VERBOSE("Country ID (for DOS): ");
+		id = -1; /* natspec_get_country_id(); */
+		printf("%d\n", id);
+		if (!info)
+			exit(0);
 	}
 	if (fcodepage || info)
 	{
 		int cp;
-		if (verbose) printf("Codepage of DOS: ");
+		VERBOSE("Codepage of DOS: ");
 		cp = natspec_get_codepage_by_charset(
 			natspec_get_charset_by_locale(NATSPEC_DOSCS, locale));
-		printf("%d", cp);
-		if (verbose) puts("");
-		if (!info) exit(0);
+		printf("%d\n", cp);
+		if (!info)
+			exit(0);
 	}
+
 	if (info)
 	{
 		char *types[]={"UNIX","WIN","DOS","MAC"};
@@ -220,12 +238,16 @@ int main(int argc, const char** argv)
 #endif
 		printf("\tnatspec_get_charset: %s\n",natspec_get_charset());
 	}
+
 	if (charset_type)
 		get_charset(charset_type);
 	is_utf8 = natspec_locale_is_utf8("");
-	if (verbose)
-		printf("Current locale is%sin UTF8 encoding\n",(is_utf8 ? " " : " NOT "));
-	if (utf8 && !info)
-		return is_utf8 ? 0 : 1;
+
+	if (utf8 || info)
+	{
+		VERBOSE("Current locale is%sin UTF8 encoding\n",(is_utf8 ? " " : " NOT "));
+		if (!info)
+			return is_utf8 ? 0 : 1;
+	}
 	return 0;
 }
